@@ -1,5 +1,5 @@
 """Standalone sphinx theme based on the official Godot documentation theme."""
-__version__ = "0.3.1"
+__version__ = "0.4.1"
 __version_info__ = tuple((int(num) if num.isdigit() else num for num in __version__.replace("-", ".", 1).split(".")))
 
 from pathlib import Path
@@ -9,8 +9,8 @@ templates_path = [str(_file_path / Path("templates"))]
 source_encoding = "utf-8-sig"
 html_static_path = [str(_file_path / Path("static"))]
 html_extra_path = [str(_file_path / Path("robots.txt"))]
-html_css_files = [str(_file_path / Path("static") / Path("css") / Path("custom.css"))]
-html_js_files = [str(_file_path / Path("static") / Path("js") / Path("custom.js"))]
+html_css_files = [str(_file_path / Path("css") / Path("custom.css"))]
+html_js_files = [str(_file_path / Path("js") / Path("custom.js"))]
 
 notfound_context = {
     "title": "Page not found",
